==> netboot_0.4.orig.tar.gz: netboot-0.4.orig/bootrom/kernel/boot/bootpriv.h <==
/*
 **************************************************************************
 *
 * Boot-ROM-Code to load an operating system across a TCP/IP network.
 *
 * Module:  bootpriv.h
 * Purpose: Miscellaeous definitions for the boot loader routines
 * Entries: none
 *
 **************************************************************************
 *
 * Copyright (C) 1995,1996 Gero Kuhlmann <gero@gkminix.han.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


/*
 **************************************************************************
 *
 * External routines:
 */

/* Determine amount of conventional memory */
extern unsigned long convmem(void);

/* Determine amount of extended memory */
extern unsigned long extmem(void);

/* Copy memory block to address given as long word */
extern void lmove(unsigned long dest, void *src, int len);

/* Call boot image */
extern void exec_image(int mode, void far *exec, void far *head,
							void far *param);
/* Load a bootblock from disk */
extern int loaddisk(unsigned char *name, unsigned short loadseg);

==> netboot-0.9.8.tar.gz: netboot-0.9.8/bootrom/kernel/boot/bootpriv.h <==
/*
 **************************************************************************
 *
 * Boot-ROM-Code to load an operating system across a TCP/IP network.
 *
 * Module:  bootpriv.h
 * Purpose: Miscellaeous definitions for the boot loader routines
 * Entries: none
 *
 **************************************************************************
 *
 * Copyright (C) 1995-2003 Gero Kuhlmann <gero@gkminix.han.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: bootpriv.h,v 1.4 2003/01/25 23:29:41 gkminix Exp $
 */

#ifndef _KERNEL_BOOT_BOOTPRIV_H
#define _KERNEL_BOOT_BOOTPRIV_H
#ifndef _USE_ASSEMBLER


/*
 **************************************************************************
 *
 * We need some includes before we can include this file
 */
#include <general.h>



/*
 **************************************************************************
 *
 * External routines:
 */

/* Determine amount of conventional memory */
extern unsigned long convmem __P((void));

/* Determine amount of extended memory */
extern unsigned long extmem __P((void));

/* Call boot image */
extern int exec_image __P((int mode, unsigned long exec, unsigned long head,
						void *param, int drive));
/* Load a bootblock from disk */
extern int loaddisk __P((unsigned char *name, unsigned long buffer,
					unsigned long *header, int *drive));


#endif				/* _USE_ASSEMBLER */
#endif				/* _KERNEL_BOOT_BOOTPRIV_H */
